<?php


namespace App\Http\Controllers\Api;
use App\Models\User;
use App\Models\UserExtModel;
use App\Models\UserInfoModel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class UserController extends Controller
{
    /**
     * 选择性别
     */
    public function checksex(Request $request){
        $user = auth('api')->user();
        $validator = Validator::make($request->all(), [
            'sex' => 'required'
        ], [
            'mobile.required'=>"性别必须",
        ]);
        if ($validator->fails()) {
            return $this->response()->errorForbidden($validator->messages()->first());
        }
        $user->sex = $request->sex;
        if (!$user->save()) {
            return $this->response->errorForbidden('设置性别失败');
        }
        return $this->response->noContent();
    }

    /**
     * 设置资料（初次登录）
     */
    public function setinfo(Request $request){
        $user = auth('api')->user();

        $validator = Validator::make($request->all(), [
            'nickname' => 'required|between:2,8',
            'birthday' => 'required',
            'avatar' => 'required',
        ], [
            'nickname.required'=>"昵称不能为空",
            'nickname.between'=>"昵称长度必须在2~8之间",
            'birthday.required'=>"生日不能为空",
            'avatar.required'=>"头像不能为空",
        ]);
        if ($validator->fails()) {
            return $this->response()->errorForbidden($validator->messages()->first());
        }

        if(UserInfoModel::where(['nickname'=>$request->nickname])->where('user_id', '!=' , $user->id)->first()){
            return $this->response->errorForbidden('昵称已被使用');
        }
        //邀请码设置
        $pid = 0;
        if(isset($request->ycode) && $request->ycode!=""){
            if(!$puser = User::where(['ycode'=>$request->ycode])->first()){
                return $this->response->errorForbidden("邀请码不存在");
            }
            $pid = $puser->id;
        }

        DB::beginTransaction();
        try {
            UserInfoModel::firstOrCreate([
                'user_id' => $user->id,
                'avatar' =>$request->avatar,
                'nickname' =>$request->nickname,
                'birthday' =>$request->birthday,
            ]);
            if($pid!=0){
               $user->pid = $pid;
               $user->save();
            }
            DB::commit();
        } catch (\Exception $e) {
            DB::rollBack();
            return $this->response->errorForbidden($e->getMessage());
        }
        return $this->response->noContent();
    }

    /**
     * 获取个人资料
     */
    public function getinfo(){
        $user = auth('api')->user();
        $userinfo = UserInfoModel::where('user_id', $user->id)->first();
        return response()->json($userinfo)->setStatusCode(201);
    }

    /**
     * 获取个人更多介绍
     */
    public function getext(){
        $user = auth('api')->user();
        $userext = UserExtModel::firstOrCreate([
            "user_id"=>$user->id
        ]);
        return response()->json($userext)->setStatusCode(201);
    }

    /**
     * 修改个人资料
     */
    public function updateinfo(Request $request){
        $user = auth('api')->user();
        $validator = Validator::make($request->all(), [
            'nickname' => 'required',
            'height' => 'integer',
            'weight' => 'integer',
        ], [
            'nickname.required'=>"昵称必须",
            'height.integer'=>"身高为整数",
            'weight.integer'=>"体重为整数",
        ]);
        if ($validator->fails()) {
            return $this->response()->errorForbidden($validator->messages()->first());
        }
        $userinfo = UserInfoModel::where('user_id', $user->id)->first();
        if($request->nickname!=$userinfo->nickname){
            if(UserInfoModel::where(['nickname'=>$request->nickname])->first()){
                return $this->response->errorForbidden('昵称已被使用');
            }
        }
        if(UserInfoModel::where('user_id', $user->id)->update($request->input())){
            return $this->response->noContent();
        }else{
            return $this->response->errorForbidden("修改失败");
        }
    }

    /**
     * 修改个人更多介绍
     */
    public function updateext(Request $request){
        $user = auth('api')->user();
        if(UserExtModel::where('user_id', $user->id)->update($request->input())){
            return $this->response->noContent();
        }else{
            return $this->response->errorForbidden("修改失败");
        }
    }

    /**
     * 获取VIP
     */
    public function get_vip(){

    }


}
